<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8" />
    <link rel="shortcut icon" href="./assets/favicon-light.png" media="(prefers-color-scheme: light)">
    <link rel="shortcut icon" href="./assets/favicon-dark.png" media="(prefers-color-scheme: dark)">
    <meta name="viewport" content="width=device-width, initial-scale=1" />
    <meta name="theme-color" content="#000000" />

    <title>{{ auth_title | default("Locust") }}</title>
    <script type="module" crossorigin src="./assets/index-Ufqx__MB.js"></script>
  </head>
  <body>
    <div id="root"></div>

    <script>
        window.authArgs = {{ auth_args|tojson }}
    </script>
  </body>
</html>
